@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 """igcommit - Git routines
 
-Copyright (c) 2016, InnoGames GmbH
+Copyright (c) 2021 InnoGames GmbH
+Portions Copyright (c) 2021 Emre Hasegeli
 """
 
-from __future__ import unicode_literals
-
 from os.path import isabs, join as joinpath, normpath
 from subprocess import check_output
 
@@ -33,9 +31,8 @@ class Commit(object):
     """Routines on a single commit"""
     null_commit_id = '0000000000000000000000000000000000000000'
 
-    def __init__(self, commit_id, commit_list=None):
+    def __init__(self, commit_id):
         self.commit_id = commit_id
-        self.commit_list = commit_list
         self.content_fetched = False
         self.changed_files = None
 
@@ -51,7 +48,7 @@ class Commit(object):
     def __eq__(self, other):
         return isinstance(other, Commit) and self.commit_id == other.commit_id
 
-    def get_new_commit_list(self, branch_name):
+    def get_new_commits(self):
         """Get the list of parent new commits in order"""
         output = check_output([
             git_exe_path,
@@ -61,11 +58,8 @@ class Commit(object):
             '--all',
             '--reverse',
         ]).decode('utf-8')
-        commit_list = CommitList([], branch_name)
         for commit_id in output.splitlines():
-            commit = Commit(commit_id, commit_list)
-            commit_list.append(commit)
-        return commit_list
+            yield Commit(commit_id)
 
     def _fetch_content(self):
         content = check_output(
@@ -147,7 +141,7 @@ class Commit(object):
             ]).decode('utf-8')
             changed_files = []
             for line in output.splitlines():
-                line_split = line.split()
+                line_split = line.split(None, 5)
                 assert len(line_split) == 6
                 assert line_split[0].startswith(':')
                 file_mode = line_split[1]
@@ -262,7 +256,8 @@ class CommittedFile(object):
         """Get the symlink target as same kind of instance
 
         We just return None, if the target has no chance to be on
-        the repository."""
+        the repository.
+        """
         content = self.get_content()
         if isabs(content):
             return None
